@@ -2,7 +2,7 @@
 /*
 ################################################################################
 #
-# r8125 is the Linux device driver released for Realtek 2.5 Gigabit Ethernet
+# r8127 is the Linux device driver released for Realtek 10 Gigabit Ethernet
 # controllers with PCI-Express interface.
 #
 # Copyright(c) 2025 Realtek Semiconductor Corp. All rights reserved.
@@ -32,6 +32,9 @@
  *  US6,570,884, US6,115,776, and US6,327,625.
  ***********************************************************************************/
 
+#ifndef _LINUX_RTLEEPROM_H
+#define _LINUX_RTLEEPROM_H
+
 //EEPROM opcodes
 #define RTL_EEPROM_READ_OPCODE      06
 #define RTL_EEPROM_WRITE_OPCODE     05
@@ -41,13 +44,15 @@
 
 #define RTL_CLOCK_RATE  3
 
-void rtl8125_eeprom_type(struct rtl8125_private *tp);
-void rtl8125_eeprom_cleanup(struct rtl8125_private *tp);
-u16 rtl8125_eeprom_read_sc(struct rtl8125_private *tp, u16 reg);
-void rtl8125_eeprom_write_sc(struct rtl8125_private *tp, u16 reg, u16 data);
-void rtl8125_shift_out_bits(struct rtl8125_private *tp, int data, int count);
-u16 rtl8125_shift_in_bits(struct rtl8125_private *tp);
-void rtl8125_raise_clock(struct rtl8125_private *tp, u8 *x);
-void rtl8125_lower_clock(struct rtl8125_private *tp, u8 *x);
-void rtl8125_stand_by(struct rtl8125_private *tp);
-void rtl8125_set_eeprom_sel_low(struct rtl8125_private *tp);
+void rtl8127_eeprom_type(struct rtl8127_private *tp);
+void rtl8127_eeprom_cleanup(struct rtl8127_private *tp);
+u16 rtl8127_eeprom_read_sc(struct rtl8127_private *tp, u16 reg);
+void rtl8127_eeprom_write_sc(struct rtl8127_private *tp, u16 reg, u16 data);
+void rtl8127_shift_out_bits(struct rtl8127_private *tp, int data, int count);
+u16 rtl8127_shift_in_bits(struct rtl8127_private *tp);
+void rtl8127_raise_clock(struct rtl8127_private *tp, u8 *x);
+void rtl8127_lower_clock(struct rtl8127_private *tp, u8 *x);
+void rtl8127_stand_by(struct rtl8127_private *tp);
+void rtl8127_set_eeprom_sel_low(struct rtl8127_private *tp);
+
+#endif /* _LINUX_RTLEEPROM_H */
