@@ -2,7 +2,7 @@
 /*
 ################################################################################
 #
-# r8125 is the Linux device driver released for Realtek 2.5 Gigabit Ethernet
+# r8127 is the Linux device driver released for Realtek 10 Gigabit Ethernet
 # controllers with PCI-Express interface.
 #
 # Copyright(c) 2025 Realtek Semiconductor Corp. All rights reserved.
@@ -40,12 +40,14 @@
 #include <linux/in.h>
 #include <linux/ethtool.h>
 #include <asm/uaccess.h>
-#include "r8125.h"
+#include "r8127.h"
+#include "r8127_fiber.h"
 #include "rtl_eeprom.h"
 #include "rtltool.h"
 
-int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
+int rtl8127_tool_ioctl(struct rtl8127_private *tp, struct ifreq *ifr)
 {
+        struct rtltool_sds_cmd *sds_cmd;
         struct rtltool_cmd my_cmd;
         unsigned long flags;
         int ret;
@@ -53,6 +55,7 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
         if (copy_from_user(&my_cmd, ifr->ifr_data, sizeof(my_cmd)))
                 return -EFAULT;
 
+        sds_cmd = (struct rtltool_sds_cmd*)&my_cmd;
         ret = 0;
         switch (my_cmd.cmd) {
         case RTLTOOL_READ_MAC:
@@ -98,9 +101,9 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 break;
 
         case RTLTOOL_READ_PHY:
-                r8125_spin_lock(&tp->phy_lock, flags);
-                my_cmd.data = rtl8125_mdio_prot_read(tp, my_cmd.offset);
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
+                my_cmd.data = rtl8127_mdio_prot_read(tp, my_cmd.offset);
+                r8127_spin_unlock(&tp->phy_lock, flags);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -109,13 +112,13 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 break;
 
         case RTLTOOL_WRITE_PHY:
-                r8125_spin_lock(&tp->phy_lock, flags);
-                rtl8125_mdio_prot_write(tp, my_cmd.offset, my_cmd.data);
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
+                rtl8127_mdio_prot_write(tp, my_cmd.offset, my_cmd.data);
+                r8127_spin_unlock(&tp->phy_lock, flags);
                 break;
 
         case RTLTOOL_READ_EPHY:
-                my_cmd.data = rtl8125_ephy_read(tp, my_cmd.offset);
+                my_cmd.data = rtl8127_ephy_read(tp, my_cmd.offset);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -124,13 +127,13 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 break;
 
         case RTLTOOL_WRITE_EPHY:
-                rtl8125_ephy_write(tp, my_cmd.offset, my_cmd.data);
+                rtl8127_ephy_write(tp, my_cmd.offset, my_cmd.data);
                 break;
 
         case RTLTOOL_READ_ERI:
                 my_cmd.data = 0;
                 if (my_cmd.len==1 || my_cmd.len==2 || my_cmd.len==4) {
-                        my_cmd.data = rtl8125_eri_read(tp, my_cmd.offset, my_cmd.len, ERIAR_ExGMAC);
+                        my_cmd.data = rtl8127_eri_read(tp, my_cmd.offset, my_cmd.len, ERIAR_ExGMAC);
                 } else {
                         ret = -EOPNOTSUPP;
                         break;
@@ -145,7 +148,7 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
 
         case RTLTOOL_WRITE_ERI:
                 if (my_cmd.len==1 || my_cmd.len==2 || my_cmd.len==4) {
-                        rtl8125_eri_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data, ERIAR_ExGMAC);
+                        rtl8127_eri_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data, ERIAR_ExGMAC);
                 } else {
                         ret = -EOPNOTSUPP;
                         break;
@@ -192,7 +195,7 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 break;
 
         case RTLTOOL_READ_EEPROM:
-                my_cmd.data = rtl8125_eeprom_read_sc(tp, my_cmd.offset);
+                my_cmd.data = rtl8127_eeprom_read_sc(tp, my_cmd.offset);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -201,13 +204,13 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 break;
 
         case RTLTOOL_WRITE_EEPROM:
-                rtl8125_eeprom_write_sc(tp, my_cmd.offset, my_cmd.data);
+                rtl8127_eeprom_write_sc(tp, my_cmd.offset, my_cmd.data);
                 break;
 
         case RTL_READ_OOB_MAC:
-                rtl8125_oob_mutex_lock(tp);
-                my_cmd.data = rtl8125_ocp_read(tp, my_cmd.offset, 4);
-                rtl8125_oob_mutex_unlock(tp);
+                rtl8127_oob_mutex_lock(tp);
+                my_cmd.data = rtl8127_ocp_read(tp, my_cmd.offset, 4);
+                rtl8127_oob_mutex_unlock(tp);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -218,23 +221,23 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 if (my_cmd.len == 0 || my_cmd.len > 4)
                         return -EOPNOTSUPP;
 
-                rtl8125_oob_mutex_lock(tp);
-                rtl8125_ocp_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data);
-                rtl8125_oob_mutex_unlock(tp);
+                rtl8127_oob_mutex_lock(tp);
+                rtl8127_ocp_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data);
+                rtl8127_oob_mutex_unlock(tp);
                 break;
 
         case RTL_ENABLE_PCI_DIAG:
-                r8125_spin_lock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
                 tp->rtk_enable_diag = 1;
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_unlock(&tp->phy_lock, flags);
 
                 dprintk("enable rtk diag\n");
                 break;
 
         case RTL_DISABLE_PCI_DIAG:
-                r8125_spin_lock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
                 tp->rtk_enable_diag = 0;
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_unlock(&tp->phy_lock, flags);
 
                 dprintk("disable rtk diag\n");
                 break;
@@ -243,7 +246,7 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 if (my_cmd.offset % 2)
                         return -EOPNOTSUPP;
 
-                my_cmd.data = rtl8125_mac_ocp_read(tp, my_cmd.offset);
+                my_cmd.data = rtl8127_mac_ocp_read(tp, my_cmd.offset);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -254,13 +257,13 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 if ((my_cmd.offset % 2) || (my_cmd.len != 2))
                         return -EOPNOTSUPP;
 
-                rtl8125_mac_ocp_write(tp, my_cmd.offset, (u16)my_cmd.data);
+                rtl8127_mac_ocp_write(tp, my_cmd.offset, (u16)my_cmd.data);
                 break;
 
         case RTL_DIRECT_READ_PHY_OCP:
-                r8125_spin_lock(&tp->phy_lock, flags);
-                my_cmd.data = rtl8125_mdio_prot_direct_read_phy_ocp(tp, my_cmd.offset);
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
+                my_cmd.data = rtl8127_mdio_prot_direct_read_phy_ocp(tp, my_cmd.offset);
+                r8127_spin_unlock(&tp->phy_lock, flags);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -269,21 +272,21 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
                 break;
 
         case RTL_DIRECT_WRITE_PHY_OCP:
-                r8125_spin_lock(&tp->phy_lock, flags);
-                rtl8125_mdio_prot_direct_write_phy_ocp(tp, my_cmd.offset, my_cmd.data);
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
+                rtl8127_mdio_prot_direct_write_phy_ocp(tp, my_cmd.offset, my_cmd.data);
+                r8127_spin_unlock(&tp->phy_lock, flags);
                 break;
 
-#ifdef ENABLE_FIBER_SUPPORT
-        case RTL_READ_FIBER_PHY:
-                if (!HW_FIBER_STATUS_CONNECTED(tp)) {
+        case RTL_READ_SDS_PHY:
+                if (!HW_FIBER_MODE_ENABLED(tp)) {
                         ret = -EOPNOTSUPP;
                         break;
                 }
 
-                r8125_spin_lock(&tp->phy_lock, flags);
-                my_cmd.data = rtl8125_fiber_mdio_read(tp, my_cmd.offset);
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
+                sds_cmd->data = rtl8127_sds_phy_read_8127(tp, sds_cmd->index,
+                                sds_cmd->page, sds_cmd->addr);
+                r8127_spin_unlock(&tp->phy_lock, flags);
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
                         break;
@@ -291,17 +294,17 @@ int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr)
 
                 break;
 
-        case RTL_WRITE_FIBER_PHY:
-                if (!HW_FIBER_STATUS_CONNECTED(tp)) {
+        case RTL_WRITE_SDS_PHY:
+                if (!HW_FIBER_MODE_ENABLED(tp)) {
                         ret = -EOPNOTSUPP;
                         break;
                 }
 
-                r8125_spin_lock(&tp->phy_lock, flags);
-                rtl8125_fiber_mdio_write(tp, my_cmd.offset, my_cmd.data);
-                r8125_spin_unlock(&tp->phy_lock, flags);
+                r8127_spin_lock(&tp->phy_lock, flags);
+                rtl8127_sds_phy_write_8127(tp, sds_cmd->index, sds_cmd->page,
+                                           sds_cmd->addr, sds_cmd->data);
+                r8127_spin_unlock(&tp->phy_lock, flags);
                 break;
-#endif /* ENABLE_FIBER_SUPPORT */
 
         default:
                 ret = -EOPNOTSUPP;
