@@ -2,7 +2,7 @@
 /*
 ################################################################################
 #
-# r8125 is the Linux device driver released for Realtek 2.5 Gigabit Ethernet
+# r8127 is the Linux device driver released for Realtek 10 Gigabit Ethernet
 # controllers with PCI-Express interface.
 #
 # Copyright(c) 2025 Realtek Semiconductor Corp. All rights reserved.
@@ -66,6 +66,9 @@ enum rtl_cmd {
         RTL_READ_FIBER_PHY,
         RTL_WRITE_FIBER_PHY,
 
+        RTL_READ_SDS_PHY,
+        RTL_WRITE_SDS_PHY,
+
         RTLTOOL_INVALID
 };
 
@@ -76,6 +79,15 @@ struct rtltool_cmd {
         __u32	data;
 };
 
+struct rtltool_sds_cmd {
+        __u32	cmd;
+        __u16	index;
+        __u16	page;
+        __u16	addr;
+        __u16	len;
+        __u32	data;
+};
+
 enum mode_access {
         MODE_NONE=0,
         MODE_READ,
@@ -83,7 +95,7 @@ enum mode_access {
 };
 
 #ifdef __KERNEL__
-int rtl8125_tool_ioctl(struct rtl8125_private *tp, struct ifreq *ifr);
+int rtl8127_tool_ioctl(struct rtl8127_private *tp, struct ifreq *ifr);
 #endif
 
 #endif /* _LINUX_RTLTOOL_H */
